@@ -1,5 +1,14 @@
 requiet("tibble")
 
+test_that("gof_map = NA", {
+    mod <- lm(mpg ~ hp, mtcars)
+    tab1 <- modelsummary(mod, output = "data.frame", gof_map = NA)
+    tab2 <- modelsummary(mod, output = "data.frame", gof_omit = ".*")
+    expect_equal(tab1, tab2)
+    expect_false("gof" %in% tab1$part)
+    expect_false("gof" %in% tab2$part)
+})
+   
 test_that("gof_map inputs are equivalent", {
     mod <- lm(mpg ~ hp, mtcars)
     gm <- tribble(
